env

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 20, 2017 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package env has a type to store common environment related items sql db, logger, etc. as well as a constructor-like function to instantiate it

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Env

type Env struct {
	Logger *zap.Logger
	DS     *datastore.Datastore
}

Env type stores common environment related items

func NewEnv

func NewEnv() (*Env, error)

NewEnv constructs Env type to be passed around to functions

Jump to